@@ -46,22 +46,22 @@ class SimpleSshDeployer(_DeployStrategyAbstractInterface):
         
         .. warning::
         
-            Поддерживается только в Linux
+            Поддерживается только в Linux либо в Windows cygwin.
 
     """
     def __init__(self, app):
         self.app = app
     
-    def push(self):
+    def push(self, *a, **k):
         self.archName = "/tmp/%s.zip"%str(uuid.uuid4())
         self.app.console.execute("zip -r -o %s *"%self.archName)
         self.app.ssh.upload_file(self.archName, self.archName)
         self.app.ssh.execute("unzip -o %s -d %s"%(self.archName, self.app.path))
     
-    def pull(self):
+    def pull(self, *a, **k):
         pass
 
-    def update(self, revision=None, branch=None):
+    def update(self, *a, **k):
         pass
         
 
