@@ -2,6 +2,8 @@
 from deploy_class.globals import singleton, NotOveroadedError
 import os
 import subprocess
+from deploy_class.globals import bcolors
+
 class AbstractExecuteInterface(object):
     def execute(self, *a):
         raise NotOveroadedError
@@ -22,18 +24,26 @@ class ConsoleInterface(AbstractExecuteInterface):
             string += x
         return subprocess.call(string, shell=True)
     
+def threadize(func):
+    import threading
+    def _c(*a, **k):
+        thread = threading.Thread(target = func, args = a, kwargs = k)
+        thread.start()
+    return _c
 
 import paramiko
+
 class SSHInterface(AbstractExecuteInterface):
     def __init__(self, user, password, host, home_folder, port=22):
         self.user, self.password, self.host, self.cwd, self.port = [user, password, host, home_folder, port]
         
         self.is_connected = False
 
+    @threadize
     def connect(self):
         if self.is_connected == True:
             return
-        print "Start connect to ssh server"
+        print bcolors.OKGREEN, "Start connect to ssh server", bcolors.ENDC
         self.client = paramiko.SSHClient()
         self.client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
         self.client.connect(hostname=self.host, username=self.user, password=self.password, port=self.port)
@@ -41,8 +51,14 @@ class SSHInterface(AbstractExecuteInterface):
 
         self.init_transport()
         self.is_connected = True
-        print "Connected"
+        print bcolors.OKGREEN, "Connected", bcolors.ENDC
     
+    def _waiting_for_connect(self):
+        import time
+        while not self.is_connected:
+            time.sleep(1)
+            print bcolors.WARNING, "Waiting for ssh...", bcolors.ENDC
+
     def init_transport(self):
         if not self.transport:
             self.transport = paramiko.Transport((self.host, self.port))
@@ -50,7 +66,7 @@ class SSHInterface(AbstractExecuteInterface):
             self.sftp = paramiko.SFTPClient.from_transport(self.transport)
     
     def execute(self, *a):
-        self.connect()
+        self._waiting_for_connect()
         s = 'cd '+self.cwd+";"
         for comm in a:
             if comm[-1]!=";":
@@ -61,9 +77,9 @@ class SSHInterface(AbstractExecuteInterface):
         return stdout.read() + stderr.read()
     
     def get_file(self, remote_path, local_path):
-        self.init_transport()
+        self._waiting_for_connect()
         self.sftp.get(remote_path, local_path)
     
     def upload_file(self, local_path, remote_path):
-        self.init_transport()
+        self._waiting_for_connect()
         self.sftp.put(local_path, remote_path)
\ No newline at end of file
